@@ -38,16 +38,22 @@ from .commons.endpoints import default_endpoints
     help="your API password for accessing the environment",
 )
 @click.option(
-    "--extractor", help="extractor endpoint",
+    "--extractor", help="custom extractor endpoint",
+)
+@click.option(
+    "-H",
+    "--header",
+    multiple=True,
+    help="extractor endpoint header(s) can be multiple. Similair to curl, e.g. -H 'keyheader: value' -H '2ndkeyheader: 2ndvalue'",
 )
 @click.pass_context
-def main(ctx, config_file, endpoint_env, username, password, extractor):
+def main(ctx, config_file, endpoint_env, username, password, extractor, header):
     """
     Can convert 1 invoice to xml or a directory of invoices to csv/xlsx.
     It is advised to configurate credentials and endpoints before use with: \n >> hycli config
     """
     filename = os.path.expanduser(config_file)
-    ctx.obj = {"config_file": filename, "env": endpoint_env}
+    ctx.obj = {"config_file": filename, "env": endpoint_env, "headers": header}
 
     try:
         with open(filename) as cfg:
