@@ -25,15 +25,13 @@ def to_xml(ctx, path, output):
     services = Services(ctx, check_up=True)
     spinner.succeed(f"Found file: {path}\n ")
 
-    endpoints = ctx.obj["config"]["endpoints"]
-
     # Conversion
     convert_to_xml(
         path,
         output,
-        endpoints["extractor"],
-        getattr(services, "vat_validation", None),
-        getattr(services, "validation", None),
-        getattr(services, "token", None),
+        services.extractor_endpoint,
+        services.vat_validator_endpoint,
+        services.validation_endpoint,
+        services.token,
     )
     spinner.succeed("Converted invoice to xml")
