@@ -20,6 +20,8 @@ def handle_status_code(func):
             if err.response.status_code == 401:
                 raise Exception("API credentials not correct.")
             else:
-                raise Exception(err)
+                raise Exception(
+                    f"{err}\n Response: {str(err.response._content, 'utf-8')}"
+                )
 
     return decorator
