@@ -1,34 +1,31 @@
-import os
 import json
 
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
 import click
-from filetype import guess
 
 from ..services.requests import extract_invoice
 from .commons import read_pdf, get_filenames
 
 
 def convert_to_json(path, extractor_endpoint, token, workers):
-    files = get_filenames(os.path.join(os.getcwd(), path))
+    files = get_filenames(path)
 
     with ThreadPoolExecutor(max_workers=workers) as exe:
         jobs = {
             exe.submit(
                 extract_invoice,
-                read_pdf(str(filename)),
+                read_pdf(file_path),
                 extractor_endpoint,
-                guess(str(filename)).mime,
+                file_extension,
                 token,
-            ): filename
-            for filename in files
-            if guess(str(filename)).mime
+            ): file_path
+            for file_path, file_extension in files.items()
         }
         label = f"Converting {len(jobs)} invoices"
         with click.progressbar(jobs, label=label) as bar:
             for idx, future in enumerate(as_completed(jobs)):
-                file_name = str(jobs[future]).split("/")[-1]
+                file_name = jobs[future].split("/")[-1]
                 try:
                     response = future.result(timeout=300)
 
