@@ -127,7 +127,7 @@ def merge_validation(result):
                     except (KeyError, IndexError):
                         _dict[entity].pop(-1)
             # Entity is a field with no value
-            elif not value:
+            elif value is None:
                 _dict[entity] = {
                     "@risk": "high",
                     "#text": "",
@@ -188,10 +188,8 @@ def clean_extractor(result):
         extractor_resp["entities"]["payment"]["terms"] = {}
         extractor_resp["entities"]["payment"]["terms"]["term"] = terms
 
-    del (
-        extractor_resp["probabilities"],
-        extractor_resp["infos"],
-    )
+    extractor_resp.pop("probabilities", None)
+    extractor_resp.pop("infos", None)
 
 
 def clean_validation(validation):
@@ -210,7 +208,13 @@ def escape_special_chars(value):
     Returns:
         [type] -- Field value with the 5 special characters escaped.
     """
-    special_chars = {"&": "&amp", ">": "&gt", "<": "&lt", "'": "&apos", '"': "&quot"}
+    special_chars = {
+        "&": "&amp;",
+        ">": "&gt;",
+        "<": "&lt;",
+        "'": "&apos;",
+        '"': "&quot;",
+    }
 
     for char, replace_char in special_chars.items():
         if char in value:
