@@ -21,12 +21,20 @@ def request_token(token_endpoint, username, password):
 
 
 @handle_status_code
-def extract_invoice(file, extractor_endpoint, content_type, token=None):
+def extract_invoice(
+    file,
+    extractor_endpoint,
+    content_type,
+    token=None,
+    params=("rasterization: true", "probabilities: true"),
+):
     """ Request invoice extractor """
     response = requests.post(
         url=extractor_endpoint,
         data=file,
-        params={"rasterization": "true", "probabilities": "true"},
+        params={x.split(":")[0].strip(): x.split(":")[1].strip() for x in params}
+        if params
+        else params,
         timeout=1800,
         headers={"Content-type": content_type, "Authorization": f"Bearer {token}"},
     )
